/* giblib/giblib_config.h.  Generated automatically by configure.  */
/* giblib/giblib_config.h.in.  Generated automatically from configure.ac by autoheader.  */

/* Define if you have the <dlfcn.h> header file. */
#define HAVE_DLFCN_H 1

/* Name of package */
/* #undef PACKAGE */

/* Define if you have the ANSI C header files. */
#define STDC_HEADERS 1

/* Version number of package */
/* #undef VERSION */

/* Define if using the dmalloc debugging malloc package */
/* #undef WITH_DMALLOC */
